References
==========
The implementation details of TB2J:

   `Xu He, Nicole Helbig, Matthieu J. Verstraete, Eric Bousquet, 
   TB2J: a python package for computing magnetic interaction parameters.
   Computer Physics Communications, 107938 (2021). <https://doi.org/10.1016/j.cpc.2021.107938>`__

The theoretical background for exchanges calculation is described in

-  Initial idea of Green’s function method of calculating J.

   `Liechtenstein et al. J.M.M.M. 67,65-74 (1987), (aka
   LKAG) <https://doi.org/10.1016/0304-8853(87)90721-9>`__

-  Isotropic exchange using Maximally localized Wannier function.

   `Korotin et al. Phys. Rev. B 91, 224405
   (2015) <http://link.aps.org/doi/10.1103/PhysRevB.91.224405>`__

-  Full exchange tensor.

   `Antropov et al. Physica B 237-238 (1997)
   336-340 <https://www.sciencedirect.com/science/article/pii/S0921452697002032>`__

-  Biqudratic term.

   `S. Lounis, P. H. Dederichs, Phys. Rev. B 82 180404(R)
   (2010) <https://doi.org/10.1103/PhysRevB.82.180404>`__

   `Szilva et al, Phys. Rev. Lett. 111,
   127204 <https://journals.aps.org/prl/abstract/10.1103/PhysRevLett.111.127204>`__

- Downfold method
    `I. V. Solovyev, Phys. Rev. B 103, 104428
    <https://journals.aps.org/prb/abstract/10.1103/PhysRevB.103.104428>`__
